@@ -10,90 +10,111 @@ from jade.enums import ResourceMonitorType
 from jade.models import JadeBaseModel, HpcConfig, SingularityParams
 
 
+class ResourceMonitorStats(JadeBaseModel):
+    """Defines the stats to monitor."""
+
+    cpu: bool = Field(
+        description="Monitor CPU utilization",
+        default=True,
+    )
+    disk: bool = Field(
+        description="Monitor disk/storage utilization",
+        default=False,
+    )
+    memory: bool = Field(
+        description="Monitor memory utilization",
+        default=True,
+    )
+    network: bool = Field(
+        description="Monitor network utilization",
+        default=False,
+    )
+    process: bool = Field(
+        description="Monitor per-job process utilization",
+        default=False,
+    )
+    include_child_processes: bool = Field(
+        description="Include stats from direct child processes in utilization for each job.",
+        default=True,
+    )
+    recurse_child_processes: bool = Field(
+        description="Recurse child processes to find all descendants..",
+        default=False,
+    )
+
+
 class SubmitterParams(JadeBaseModel):
     """Defines the submitter options selected by the user."""
 
     generate_reports: bool = Field(
-        title="generate_reports",
         description="Controls whether to generate reports after completion",
         default=True,
     )
     hpc_config: HpcConfig = Field(
-        title="hpc_config",
         description="HPC config options",
     )
     max_nodes: Optional[int] = Field(
-        title="max_nodes",
         description="Max number of compute nodes to use simultaneously, default is unbounded",
         default=None,
     )
     num_parallel_processes_per_node: Optional[int] = Field(
-        title="num_parallel_processes_per_node",
         description="Number of processes to run in parallel on each node",
         default=None,
         alias="num_processes",
     )
     per_node_batch_size: int = Field(
-        title="per_node_batch_size",
         description="How many jobs to assign to each node",
         default=500,
     )
     # The next two parameters are obsolete and will eventually be deleted.
     node_setup_script: Optional[str] = Field(
-        title="node_setup_script",
         description="Script to run on each node before starting jobs",
         default=None,
     )
     node_shutdown_script: Optional[str] = Field(
-        title="node_shutdown_script",
         description="Script to run on each node after completing jobs",
         default=None,
     )
     poll_interval: int = Field(
-        title="poll_interval",
         description="Interval in seconds on which to poll jobs for status",
         default=10,
     )
     resource_monitor_interval: Optional[int] = Field(
-        title="resource_monitor_interval",
         description="Interval in seconds on which to collect resource stats. Disable monitoring "
         "by setting this to None/null."
         "summaries of stats.",
         default=10,
     )
     resource_monitor_type: ResourceMonitorType = Field(
-        title="resource_monitor_type",
         description=f"Type of resource monitoring to perform. Options: {[x.value for x in ResourceMonitorType]}",
         default=ResourceMonitorType.AGGREGATION,
     )
+    resource_monitor_stats: ResourceMonitorStats = Field(
+        description="Resource utilization stats to monitor",
+        default=ResourceMonitorStats(),
+    )
     try_add_blocked_jobs: bool = Field(
-        title="try_add_blocked_jobs",
         description="Add blocked jobs to a batch if all blocking jobs are in the batch. "
         "Be aware of time constraints.",
         default=True,
     )
     time_based_batching: bool = Field(
-        title="time_based_batching",
         description="Use time-based batching instead of job-count-based batching",
         default=False,
     )
     dry_run: bool = Field(
-        title="dry_run",
         description="Dry run mode; don't start any jobs",
         default=False,
     )
     verbose: bool = Field(
-        title="verbose",
         description="Enable debug logging",
         default=False,
     )
     singularity_params: Optional[SingularityParams] = Field(
-        title="singularity_params",
         description="Singularity container parameters",
         default=None,
     )
     distributed_submitter: bool = Field(
-        title="distributed_submitter",
         description="Submit new jobs and update status on compute nodes.",
         default=True,
     )
